// Copyright (c) 2010 Oleg Oshmyan <chortos@inbox.lv>

#include <algorithm>
#include <cstdio>
using namespace std;

struct point
{
	int x, y;
	
	point (operator +)(const point b) const
	{
		return (point) { x + b.x, y + b.y };
	}
	
	point (operator -)(const point b) const
	{
		return (point) { x - b.x, y - b.y };
	}
	
	long long (operator *)(const point b) const
	{
		return (long long) x * b.y - (long long) y * b.x;
	}
};

struct fract
{
	unsigned long long p, q;
	
	bool (operator <)(const fract b) const
	{
		if (!q) return false;
		if (!b.q) return true;
		
		long long x = p / q, y = b.p / b.q;
		if (x != y) return x < y;
		else return (p % q) * b.q < (b.p % b.q) * q;
	}
	
	void cancel()
	{
		unsigned long long a = p, b = q;
		
		while (b)
		{
			unsigned long long t = a;
			a = b;
			b = t % b;
		}
		
		p /= a;
		q /= a;
	}
};

static point vertices[100000];
static int n;

// x in [l, r)
static inline bool isbetween(const point x, const point l, const point r)
{
	if (l * r > 0) return l * x <= 0 || r * x > 0;
	else return l * x <= 0 && r * x > 0;
}

static fract check(point q, point x, int kxx, int kxy, int kyx, int kyy)
{
	point oar, abr;
	
	{
		point l = vertices[0] - q;
		
		if (isbetween(x, vertices[n - 1] - q, l))
		{
			oar = vertices[n - 1];
			abr = vertices[0] - oar;
		}
		else
		{
			int first = 0, last = n - 1;
			
			while (first < last - 1)
			{
				int middle = first + last >> 1;
				point m = vertices[middle] - q;
				
				if (isbetween(x, l, m))
				{
					last = middle;
				}
				else
				{
					first = middle;
					l = m;
				}
			}
			
			oar = vertices[first];
			abr = vertices[last] - vertices[first];
		}
	}
	
	point ab = { kxx * abr.x + kxy * abr.y, kyx * abr.x + kyy * abr.y };
	point oa = { kxx * oar.x + kxy * oar.y, kyx * oar.x + kyy * oar.y };
	point oq = { kxx *   q.x + kxy *   q.y, kyx *   q.x + kyy *   q.y };
	
	fract f = { ((long long) oq.x - oq.y - oa.x + oa.y) * ab.x + ((long long) oa.x - oq.x) * ((long long) ab.x - ab.y), (long long) ab.x - ab.y };
	if (ab.x < ab.y) { f.p = -f.p; f.q = -f.q; }
	f.cancel();
	return f;
}

int main()
{
	FILE *f = fopen("kvadrats.dat", "r");
	
	int m;
	fscanf(f, "%u%u", &n, &m);
	
	for (int i = 0; i < n; ++i)
	{
		fscanf(f, "%d%d", &vertices[i].x, &vertices[i].y);
	}
	
	point centers[100000];
	
	for (int i = 0; i < m; ++i)
	{
		fscanf(f, "%d%d", &centers[i].x, &centers[i].y);
	}
	
	freopen("kvadrats.rez", "w", f);
	
	for (int i = 0; i < m; ++i)
	{
		fract x = check(centers[i], (point) { 1, 1 }, 1, 0, 0, 1);
		x = min(x, check(centers[i], (point) { 1, -1 }, 0, -1, 1, 0));
		x = min(x, check(centers[i], (point) { -1, -1 }, -1, 0, 0, -1));
		x = min(x, check(centers[i], (point) { -1, 1 }, 0, 1, -1, 0));
		
		if (x.q % 2) x.p *= 2;
		else x.q /= 2;
		
		fprintf(f, "%I64u %I64u\n", x.p, x.q);
	}
	
	fclose(f);
	return 0;
}
