# Copyright (c) 2010 Oleg Oshmyan <chortos@inbox.lv>

import fractions

class Point:
	__slots__ = 'x', 'y'
	
	def __init__(self, x, y):
		self.x = x
		self.y = y
	
	def __add__(self, other):
		return Point(self.x + other.x, self.y + other.y)
	
	def __sub__(self, other):
		return Point(self.x - other.x, self.y - other.y)
	
	def __mul__(self, other):
		return self.x * other.y - self.y * other.x

# x in [l, r)
def isbetween(x, l, r):
	if l * r > 0: return l * x <= 0 or r * x > 0
	else: return l * x <= 0 and r * x > 0

def check(q, x, kxx, kxy, kyx, kyy):
	l = vertices[0] - q
	
	if isbetween(x, vertices[n - 1] - q, l):
		oar = vertices[n - 1]
		abr = vertices[0] - oar
	else:
		first, last = 0, n - 1
		
		while first < last - 1:
			middle = first + last >> 1
			m = vertices[middle] - q
			
			if isbetween(x, l, m):
				last = middle
			else:
				first = middle
				l = m
		
		oar = vertices[first]
		abr = vertices[last] - oar
	
	ab = Point(kxx * abr.x + kxy * abr.y, kyx * abr.x + kyy * abr.y)
	oa = Point(kxx * oar.x + kxy * oar.y, kyx * oar.x + kyy * oar.y)
	oq = Point(kxx *   q.x + kxy *   q.y, kyx *   q.x + kyy *   q.y)
	
	return fractions.Fraction((oq.x - oq.y - oa.x + oa.y) * ab.x + (oa.x - oq.x) * (ab.x - ab.y), ab.x - ab.y)

f = open('kvadrats.dat')
n, m = map(int, f.readline().split())

vertices = []

for i in xrange(n):
	vertices.append(Point(*map(int, f.readline().split())))

centers = []

for i in xrange(m):
	centers.append(Point(*map(int, f.readline().split())))

f.close()
f = open('kvadrats.rez', 'w')

for center in centers:
	x = min(check(center, Point( 1,  1),  1,  0,  0,  1),
	        check(center, Point( 1, -1),  0, -1,  1,  0),
	        check(center, Point(-1, -1), -1,  0,  0, -1),
	        check(center, Point(-1,  1),  0,  1, -1,  0)) * 2
	print >>f, x.numerator, x.denominator

f.close()