// Copyright (c) 2010 Oleg Oshmyan <chortos@inbox.lv>
// ...Yes, the copyright notice is back! ^_^

#include <algorithm>
#include <cstdio>
using namespace std;

struct vertsegm
{
	long long x, ytop, ybottom;
	
	bool (operator <)(const vertsegm b) const
	{
		if (x != b.x) return x < b.x;
		else return ybottom < b.ybottom;
	}
};

struct horsegm
{
	long long y, xleft, xright;
	
	bool (operator <)(const horsegm b) const
	{
		if (y != b.y) return y < b.y;
		else return xleft < b.xleft;
	}
};

int main()
{
	static vertsegm vert[300000];
	vertsegm *vend = vert;
	static horsegm horiz[300000];
	horsegm *hend = horiz;
	
	FILE *f = fopen("romba.dat", "r");
	
	int n;
	fscanf(f, "%u", &n);
	
	//enum dir { RIGHT, UP, LEFT, DOWN } dir = RIGHT;
#define RIGHT 0
#define UP 1
#define LEFT 2
#define DOWN 3
	int dir = 0;
	long long x = 0, y = 0;
	
	while (n--)
	{
		char c;
		fscanf(f, " %c", &c);
		
		if (c == 'T')
		{
			int len;
			fscanf(f, "%u", &len);
			
			switch (dir)
			{
			case RIGHT:
				hend->y = y;
				hend->xleft = x + 1;
				hend->xright = x += len;
				++hend;
				break;
				
			case UP:
				vend->x = x;
				vend->ybottom = y + 1;
				vend->ytop = y += len;
				++vend;
				break;
				
			case LEFT:
				hend->y = y;
				hend->xright = x - 1;
				hend->xleft = x -= len;
				++hend;
				break;
				
			case DOWN:
				vend->x = x;
				vend->ytop = y - 1;
				vend->ybottom = y -= len;
				++vend;
				break;
			
			default:
				throw "FAIL";
			}
		}
		else if (c == 'K')
		{
			dir = /*(enum dir)*/ ((dir + 1) % 4);
		}
		else if (c == 'L')
		{
			dir = /*(enum dir)*/ ((dir + 3) % 4);
		}
		else
		{
			throw "FAIL";
		}
	}
	
	sort(vert, vend);
	sort(horiz, hend);
	
	if (vend > vert) for (vertsegm *r = vert + 1, *w = vert; ; ++r)
	{
		if (r == vend)
		{
			vend = w + 1;
			break;
		}
		
		if (r->x != w->x)
		{
			*++w = *r;
		}
		else if (r->ybottom > w->ytop + 1)
		{
			*++w = *r;
		}
		else
		{
			if (r->ytop > w->ytop) w->ytop = r->ytop;
		}
	}
	
	long long minleft = 0;
	
	if (hend > horiz) for (horsegm *r = horiz + 1, *w = horiz; ; ++r)
	{
		if (r == hend)
		{
			hend = w + 1;
			break;
		}
		
		if (r->xleft < minleft) minleft = r->xleft;
		
		if (r->y != w->y)
		{
			*++w = *r;
		}
		else if (r->xleft > w->xright + 1)
		{
			*++w = *r;
		}
		else
		{
			if (r->xright > w->xright) w->xright = r->xright;
		}
	}
	
	long long answer = 0;
	
	for (vertsegm *p = vert; p != vend; ++p)
	{
		horsegm h = { p->ybottom, minleft };
		
		for (horsegm *q = lower_bound(horiz, hend, h); q != hend && p->ytop >= q->y; ++q)
		//for (horsegm *q = horiz; q != hend; ++q)
		{
			answer -= (q->xleft <= p->x && q->xright >= p->x && p->ytop >= q->y && p->ybottom <= q->y) ? 1 : 0;
		}
	}
	
	for (horsegm *p = horiz; p != hend; ++p)
	{
		answer += p->xright - p->xleft + 1;
	}
	
	for (vertsegm *p = vert; p != vend; ++p)
	{
		answer += p->ytop - p->ybottom + 1;
	}
	
	freopen("romba.rez", "w", f);
	fprintf(f, "%I64u\n", answer);
	fclose(f);
	return 0;
}
