// Copyright (c) 2010 Oleg Oshmyan <chortos@inbox.lv>
// ...Yes, the copyright notice is back! ^_^

#include <algorithm>
#include <cstdio>
using namespace std;

struct vertsegm
{
	long long x, ytop, ybottom;
};

struct horsegm
{
	long long y, xleft, xright;
};

struct event
{
	long long x;
	int ytop, ybottom;
	bool on;
	
	bool (operator <)(const event b) const
	{
		if (x != b.x) return x < b.x;
		else return on && !b.on;
	}
};

static long long ys[300000*2];
static long long *ysend = ys;

struct node
{
	int start, end, middle;
	node *left, *right;
	unsigned long long v;
	int ncovered;
	
	unsigned long long get(int st, int en) const
	{
		if (st <= start && en >= end)
		{
			return v;
		}
		else if (ncovered)
		{
			return ys[min(en, end)] - ys[max(st, start)];
		}
		else if (en <= middle)
		{
			return left->get(st, en);
		}
		else if (st >= middle)
		{
			return right->get(st, en);
		}
		else
		{
			return left->get(st, en) + right->get(st, en);
		}
	}
	
	void incr(int st, int en)
	{
		if (st <= start && en >= end)
		{
			++ncovered;
			v = ys[end] - ys[start];
		}
		else if (en <= middle)
		{
			left->incr(st, en);
			if (!ncovered) v = left->v + right->v;
		}
		else if (st >= middle)
		{
			right->incr(st, en);
			if (!ncovered) v = left->v + right->v;
		}
		else
		{
			left->incr(st, en);
			right->incr(st, en);
			if (!ncovered) v = left->v + right->v;
		}
	}
	
	void decr(int st, int en)
	{
		if (st <= start && en >= end)
		{
			if (!--ncovered)
			{
				if (start != middle) v = left->v + right->v;
				else v = 0;
			}
		}
		else if (en <= middle)
		{
			left->decr(st, en);
			if (!ncovered) v = left->v + right->v;
		}
		else if (st >= middle)
		{
			right->decr(st, en);
			if (!ncovered) v = left->v + right->v;
		}
		else
		{
			left->decr(st, en);
			right->decr(st, en);
			if (!ncovered) v = left->v + right->v;
		}
	}
};

int main()
{
	static vertsegm vert[300000];
	vertsegm *vend = vert;
	static horsegm horiz[300000];
	horsegm *hend = horiz;
	
	FILE *f = fopen("romba.dat", "r");
	
	int n;
	fscanf(f, "%u", &n);
	
	enum dir { RIGHT, UP, LEFT, DOWN } dir = RIGHT;
	long long x = 0, y = 0;
	
	while (n--)
	{
		char c;
		fscanf(f, " %c", &c);
		
		if (c == 'T')
		{
			int len;
			fscanf(f, "%u", &len);
			
			switch (dir)
			{
			case RIGHT:
				hend->y = y;
				hend->xleft = x + 1;
				hend->xright = x += len;
				++hend;
				break;
				
			case UP:
				vend->x = x;
				vend->ybottom = y + 1;
				vend->ytop = y += len;
				++vend;
				break;
				
			case LEFT:
				hend->y = y;
				hend->xright = x - 1;
				hend->xleft = x -= len;
				++hend;
				break;
				
			case DOWN:
				vend->x = x;
				vend->ytop = y - 1;
				vend->ybottom = y -= len;
				++vend;
				break;
			}
		}
		else if (c == 'K')
		{
			dir = (enum dir) ((dir + 1) % 4);
		}
		else
		{
			dir = (enum dir) ((dir + 3) % 4);
		}
	}
	
	for (vertsegm *p = vert; p != vend; ++p)
	{
		*ysend++ = p->ytop + 1;
		*ysend++ = p->ybottom;
	}
	
	for (horsegm *p = horiz; p != hend; ++p)
	{
		*ysend++ = p->y;
		*ysend++ = p->y + 1;
	}
	
	sort(ys, ysend);
	ysend = unique(ys, ysend);
	
	static event events[300000*2];
	event *eend = events;
	
	for (vertsegm *p = vert; p != vend; ++p)
	{
		eend->x = p->x;
		
		int ybottom = lower_bound(ys, ysend, p->ybottom) - ys;
		eend->ybottom = ybottom;
		
		int ytop = lower_bound(ys, ysend, p->ytop + 1) - ys;
		eend->ytop = ytop;
		
		eend->on = true;
		++eend;
		eend->x = p->x;
		eend->ybottom = ybottom;
		eend->ytop = ytop;
		eend->on = false;
		++eend;
	}
	
	for (horsegm *p = horiz; p != hend; ++p)
	{
		int y = lower_bound(ys, ysend, p->y) - ys;
		
		eend->x = p->xleft;
		eend->ytop = 1 + (eend->ybottom = y);
		eend->on = true;
		++eend;
		
		eend->x = p->xright;
		eend->ytop = 1 + (eend->ybottom = y);
		eend->on = false;
		++eend;
	}
	
	sort(events, eend);
	
	static node tree[300000*2*2-1];
	tree->start = 0;
	tree->end = ysend - ys;
	tree->v = tree->ncovered = 0;
	
	for (node *r = tree, *w = tree + 1; r != w; ++r)
	{
		r->middle = r->start + r->end >> 1;
		
		if (r->middle != r->start)
		{
			w->start = r->start;
			w->end = r->middle;
			w->v = w->ncovered = 0;
			r->left = w++;
			
			w->start = r->middle;
			w->end = r->end;
			w->v = w->ncovered = 0;
			r->right = w++;
		}
	}
	
	unsigned long long answer = 0, lastans = 0;
	long long lastx = events->x;
	
	for (event *p = events; p != eend; ++p)
	{
		if (lastx < p->x)
		{
			answer += (p->x - lastx) * tree->v;
			lastans = answer;
		}
		
		if (p->on)
		{
			answer += ys[p->ytop] - ys[p->ybottom] - tree->get(p->ybottom, p->ytop);
			tree->incr(p->ybottom, p->ytop);
		}
		else
		{
			tree->decr(p->ybottom, p->ytop);
		}
		
		lastx = p->x;
	}
	
	freopen("romba.rez", "w", f);
	fprintf(f, "%I64u\n", answer);
	fclose(f);
	return 0;
}
